==> firebase_repository-1.0.8.tar.gz: lib/src/models/dieta.dart <==
import 'package:flutter/foundation.dart';
import 'package:meta/meta.dart';
import '../entities/entities.dart';
import 'detalle.dart';

@immutable
class Dieta{
  final String uuid;
  final bool activo;
  final int agua;
  final double calcio;
  final double costo;
  final double fdn;
  final double fosforo;
  final double mcal;
  final double ms;
  final String nombre;
  final double porcentaje;
  final double prot;
  final double talcual;
  final String type;


  Dieta({this.uuid, this.activo, this.agua, this.calcio, this.costo, this.fdn,
      this.fosforo, this.mcal, this.ms, this.nombre, this.porcentaje, this.prot,
      this.talcual, this.type});

  Dieta copyWith({String uuid, bool activo, int agua, double calcio, double costo, double fdn, double fosforo,
  double mcal, double ms, String nombre, double porcentaje, double prot, double talcual, String type}){
    return Dieta(
      uuid: uuid ?? this.uuid,
      activo: activo ?? this.activo,
      agua: agua ?? this.agua,
      calcio: calcio ?? this.calcio,
      costo: costo ?? this.costo,
      fdn: fdn ?? this.fdn,
      fosforo: fosforo ?? this.fosforo,
      mcal: mcal ?? this.mcal,
      ms: ms ?? this.ms,
      nombre: nombre ?? this.nombre,
      porcentaje: porcentaje ?? this.porcentaje,
      prot: prot ?? this.prot,
      talcual: talcual ?? this.talcual,
      type: type ?? this.type,
    );
}


  @override
  String toString() {
    return 'Dieta{uuid: $uuid, activo: $activo, agua: $agua, calcio: $calcio, costo: $costo, fdn: $fdn, fosforo: $fosforo, mcal: $mcal, ms: $ms, nombre: $nombre, porcentaje: $porcentaje, prot: $prot, talcual: $talcual, type: $type}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Dieta &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              activo == other.activo &&
              agua == other.agua &&
              calcio == other.calcio &&
              costo == other.costo &&
              fdn == other.fdn &&
              fosforo == other.fosforo &&
              mcal == other.mcal &&
              ms == other.ms &&
              nombre == other.nombre &&
              porcentaje == other.porcentaje &&
              prot == other.prot &&
              talcual == other.talcual &&
              type == other.type;

  @override
  int get hashCode =>
      uuid.hashCode ^
      activo.hashCode ^
      agua.hashCode ^
      calcio.hashCode ^
      costo.hashCode ^
      fdn.hashCode ^
      fosforo.hashCode ^
      mcal.hashCode ^
      ms.hashCode ^
      nombre.hashCode ^
      porcentaje.hashCode ^
      prot.hashCode ^
      talcual.hashCode ^
      type.hashCode;

  DietaEntity toEntity(){
    return DietaEntity(uuid, activo, agua, calcio, costo, fdn, fosforo, mcal, ms, nombre, porcentaje, prot, talcual, type);
  }
  
  static Dieta fromEntity(DietaEntity entity){
    return Dieta(
      talcual: entity.talcual,
      porcentaje: entity.porcentaje,
      fosforo: entity.fosforo,
      calcio: entity.calcio,
      agua: entity.agua,
      activo: entity.activo,
      uuid: entity.uuid,
      prot: entity.prot,
      fdn: entity.fdn,
      nombre: entity.nombre,
      mcal: entity.mcal,
      costo: entity.costo,
      ms: entity.ms,
      type: entity.type,
    );
  }


}

==> firebase_repository-1.0.34.tar.gz: lib/src/models/dieta.dart <==
import 'package:flutter/foundation.dart';
import 'package:meta/meta.dart';
import '../entities/entities.dart';

@immutable
class Dieta {
  final String uuid;
  final bool activo;
  final int agua;
  final double calcio;
  final double costo;
  final double fdn;
  final double fosforo;
  final double mcal;
  final double ms;
  final String nombre;
  final double porcentaje;
  final double prot;
  final double talcual;
  final String type;
  final List<dynamic> detalles;

  Dieta(
      {this.uuid,
      this.activo,
      this.agua,
      this.calcio,
      this.costo,
      this.fdn,
      this.fosforo,
      this.mcal,
      this.ms,
      this.nombre,
      this.porcentaje,
      this.prot,
      this.talcual,
      this.type,
      this.detalles});

  Dieta copyWith(
      {String uuid,
      bool activo,
      int agua,
      double calcio,
      double costo,
      double fdn,
      double fosforo,
      double mcal,
      double ms,
      String nombre,
      double porcentaje,
      double prot,
      double talcual,
      String type,
      List<dynamic> detalles}) {
    return Dieta(
      uuid: uuid ?? this.uuid,
      activo: activo ?? this.activo,
      agua: agua ?? this.agua,
      calcio: calcio ?? this.calcio,
      costo: costo ?? this.costo,
      fdn: fdn ?? this.fdn,
      fosforo: fosforo ?? this.fosforo,
      mcal: mcal ?? this.mcal,
      ms: ms ?? this.ms,
      nombre: nombre ?? this.nombre,
      porcentaje: porcentaje ?? this.porcentaje,
      prot: prot ?? this.prot,
      talcual: talcual ?? this.talcual,
      type: type ?? this.type,
      detalles: detalles ?? this.detalles
    );
  }


  @override
  String toString() {
    return 'Dieta{uuid: $uuid, activo: $activo, agua: $agua, calcio: $calcio, costo: $costo, fdn: $fdn, fosforo: $fosforo, mcal: $mcal, ms: $ms, nombre: $nombre, porcentaje: $porcentaje, prot: $prot, talcual: $talcual, type: $type, detalles: $detalles}';
  }


  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
          other is Dieta &&
              runtimeType == other.runtimeType &&
              uuid == other.uuid &&
              activo == other.activo &&
              agua == other.agua &&
              calcio == other.calcio &&
              costo == other.costo &&
              fdn == other.fdn &&
              fosforo == other.fosforo &&
              mcal == other.mcal &&
              ms == other.ms &&
              nombre == other.nombre &&
              porcentaje == other.porcentaje &&
              prot == other.prot &&
              talcual == other.talcual &&
              type == other.type &&
              detalles == other.detalles;

  @override
  int get hashCode =>
      uuid.hashCode ^
      activo.hashCode ^
      agua.hashCode ^
      calcio.hashCode ^
      costo.hashCode ^
      fdn.hashCode ^
      fosforo.hashCode ^
      mcal.hashCode ^
      ms.hashCode ^
      nombre.hashCode ^
      porcentaje.hashCode ^
      prot.hashCode ^
      talcual.hashCode ^
      type.hashCode ^
      detalles.hashCode;

  DietaEntity toEntity() {
    return DietaEntity(uuid, activo, agua, calcio, costo, fdn, fosforo, mcal,
        ms, nombre, porcentaje, prot, talcual, type, detalles);
  }

  static Dieta fromEntity(DietaEntity entity) {
    return Dieta(
      talcual: entity.talcual,
      porcentaje: entity.porcentaje,
      fosforo: entity.fosforo,
      calcio: entity.calcio,
      agua: entity.agua,
      activo: entity.activo,
      uuid: entity.uuid,
      prot: entity.prot,
      fdn: entity.fdn,
      nombre: entity.nombre,
      mcal: entity.mcal,
      costo: entity.costo,
      ms: entity.ms,
      type: entity.type,
      detalles: entity.detalles
    );
  }
}
